=== removed directory 'docs/plugins/rabbitmq'
=== removed file 'docs/plugins/rabbitmq/rabbitmq.rst'
--- docs/plugins/rabbitmq/rabbitmq.rst	2011-03-30 19:50:29 +0000
+++ docs/plugins/rabbitmq/rabbitmq.rst	1970-01-01 00:00:00 +0000
@@ -1,70 +0,0 @@
-RabbitMQ Integration
-======================
-
-It is possible to replicate transactions directly to a `RabbitMQ <http://www.rabbitmq.org>`_ server from drizzle, this could be used to create advanced replication solutions, to visualize data, or to build triggers. For example, `RabbitReplication <http://www.rabbitreplication.org>`_ has been built to consume the messages from rabbitmq, transform them, and persist the data in drizzle, mysql, many nosql stores and even replicating directly to websockets for data visualization.
-
-Getting started
------------------------
-First install a recent version of RabbitMQ, then install librabbitmq, this is the c library for talking to the RabbitMQ server:
-
-.. code-block:: bash
-
-         $ hg clone http://hg.rabbitmq.com/rabbitmq-codegen/
-	 $ hg clone http://hg.rabbitmq.com/rabbitmq-c/
-	 $ cd rabbitmq-c
-	 $ autoreconf -f -i
-	 $ ./configure
-	 $ make
-	 $ make install
-
-Now you probably need to rebuild drizzle (the rabbitmq plugin is not built if librabbitmq is not installed), see :ref:`dependencies`.
-
-To start drizzled you need to add the replication plugins, start drizzled7 something like this (you probably want to add datadir etc as well, but these are the minimum):
-
-.. code-block:: bash
-
-         $ sbin/drizzled7 --plugin-add rabbitmq,default-replicator --rabbitmq.use-replicator default
-
-To verify that it works, you can start a generic rabbitmq listener from librabbitmq:
-
-.. code-block:: bash
-
-         $ ./amqp_listen localhost 5672 ReplicationExchange ReplicationRoutingKey
-
-And you should see something like this when you do an INSERT/CREATE/.. (just not a select) in your newly built drizzle instance:
-
-.. code-block:: bash
-      
-     Result 0
-     Frame type 1, channel 1
-     Method AMQP_BASIC_DELIVER_METHOD
-     Delivery 1, exchange ReplicationExchange routingkey ReplicationRoutingKey
-
-     00000000: 0A 17 08 01 10 87 36 18 : F0 FA D9 99 FA F1 A7 02  ......6.........
-     00000010: 20 99 81 DA 99 FA F1 A7 : 02 12 40 08 01 10 F2 FA   .........@.....
-     00000020: D9 99 FA F1 A7 02 18 FC : FA D9 99 FA F1 A7 02 2A  ...............*
-     00000030: 17 0A 06 0A 01 62 12 01 : 61 12 06 08 04 12 02 69  .....b..a......i
-     00000040: 64 12 05 08 01 12 01 74 : 32 11 08 01 10 01 1A 0B  d......t2.......
-     00000050: 0A 01 32 0A 02 61 61 10 : 00 10 00 20 01 28 01     ..2..aa.... .(.
-     0000005F:
-
-It is possible to configure what `exchange <http://www.rabbitmq.com/faq.html#managing-concepts-exchanges>`_ and various other settings, these are the available config parameters:
-
-.. code-block:: bash
-
-   --rabbitmq.host arg (=localhost)                    Host name to connect to
-   --rabbitmq.port arg (=5672)                         Port to connect to
-   --rabbitmq.virtualhost arg (=/)                     RabbitMQ virtualhost
-   --rabbitmq.username arg (=guest)                    RabbitMQ username
-   --rabbitmq.password arg (=guest)                    RabbitMQ password
-   --rabbitmq.use-replicator arg (=default_replicator) Name of the replicator 
-   --rabbitmq.exchange arg (=ReplicationExchange)      Name of RabbitMQ exchange
-   --rabbitmq.routingkey arg (=ReplicationRoutingKey)  Name of RabbitMQ routing 
-   
-
-Implementation details
------------------------
-
-* If the rabbitmq server is not available when starting drizzled, drizzled will not start
-* If the rabbitmq server goes away, the plugin will try to reconnect and resend the message 3 times, after that, the transaction is rolled back
-

=== modified file 'plugin/rabbitmq/rabbitmq_handler.cc'
--- plugin/rabbitmq/rabbitmq_handler.cc	2011-03-30 19:50:29 +0000
+++ plugin/rabbitmq/rabbitmq_handler.cc	2011-02-17 00:14:13 +0000
@@ -37,74 +37,17 @@
                                  const in_port_t rabbitMQPort, 
                                  const std::string &rabbitMQUsername, 
                                  const std::string &rabbitMQPassword, 
-                                 const std::string &rabbitMQVirtualhost, 
-				 const std::string &rabbitMQExchange, 
-				 const std::string &rabbitMQRoutingKey) 
+                                 const std::string &rabbitMQVirtualhost) 
   throw(rabbitmq_handler_exception) :
     rabbitmqConnection(amqp_new_connection()),
+    sockfd(amqp_open_socket(rabbitMQHost.c_str(), rabbitMQPort)),
     hostname(rabbitMQHost),
     port(rabbitMQPort),
     username(rabbitMQUsername),
     password(rabbitMQPassword),
-    virtualhost(rabbitMQVirtualhost),
-    exchange(rabbitMQExchange), 
-    routingKey(rabbitMQRoutingKey)
-{
-  connect();
-}
-
-RabbitMQHandler::~RabbitMQHandler()
-{
-  disconnect();
-}
-
-void RabbitMQHandler::publish(void *message, 
-                              const int length)
-throw(rabbitmq_handler_exception)
-{
-  amqp_bytes_t b;
-  b.bytes= message;
-  b.len= length;
-  
-  if (amqp_basic_publish(rabbitmqConnection,
-                         1,
-                         amqp_cstring_bytes(exchange.c_str()),
-                         amqp_cstring_bytes(routingKey.c_str()),
-                         0,
-                         0,
-                         NULL,
-                         b) < 0)
-  {
-    throw rabbitmq_handler_exception("Could not publish message");
-  }
-
-}
-
-void RabbitMQHandler::reconnect() throw(rabbitmq_handler_exception)
-{
-  disconnect();
-  connect();
-}
-
-void RabbitMQHandler::disconnect() throw(rabbitmq_handler_exception) 
-{
-  try
-  {
-    handleAMQPError(amqp_channel_close(rabbitmqConnection, 
-				       1, 
-				       AMQP_REPLY_SUCCESS),
-		    "close channel");
-    handleAMQPError(amqp_connection_close(rabbitmqConnection, 
-					  AMQP_REPLY_SUCCESS),
-		    "close connection");
-    amqp_destroy_connection(rabbitmqConnection);
-  }
-  catch(exception& e) {} // do not throw in destructorn 
-  close(sockfd);
-}
-
-void RabbitMQHandler::connect() throw(rabbitmq_handler_exception) {
-  sockfd = amqp_open_socket(hostname.c_str(), port);
+    virtualhost(rabbitMQVirtualhost)
+{
+  /* open the socket to the rabbitmq server */
   if(sockfd < 0) 
   {
     throw rabbitmq_handler_exception(_("Could not open socket, is rabbitmq running?"));
@@ -122,9 +65,48 @@
                   "rabbitmq login");
   /* open the channel */
   amqp_channel_open(rabbitmqConnection, 1);
-  handleAMQPError(amqp_get_rpc_reply(rabbitmqConnection), "RPC Reply");
-  amqp_exchange_declare(rabbitmqConnection, 1, amqp_cstring_bytes(exchange.c_str()), amqp_cstring_bytes("fanout"), 0, 0, amqp_empty_table);
-  handleAMQPError(amqp_get_rpc_reply(rabbitmqConnection), "RPC Reply");
+}
+
+RabbitMQHandler::~RabbitMQHandler()
+{
+  try
+  {
+    handleAMQPError(amqp_channel_close(rabbitmqConnection, 
+				       1, 
+				       AMQP_REPLY_SUCCESS),
+		    "close channel");
+    handleAMQPError(amqp_connection_close(rabbitmqConnection, 
+					  AMQP_REPLY_SUCCESS),
+		    "close connection");
+    amqp_destroy_connection(rabbitmqConnection);
+  }
+  catch(exception& e) {} // do not throw in destructorn 
+  
+  close(sockfd);
+}
+
+void RabbitMQHandler::publish(void *message, 
+                              const int length, 
+                              const std::string &exchangeName, 
+                              const std::string &routingKey)
+throw(rabbitmq_handler_exception)
+{
+  amqp_bytes_t b;
+  b.bytes= message;
+  b.len= length;
+  
+  if (amqp_basic_publish(rabbitmqConnection,
+                         1,
+                         amqp_cstring_bytes(exchangeName.c_str()),
+                         amqp_cstring_bytes(routingKey.c_str()),
+                         0,
+                         0,
+                         NULL,
+                         b) < 0)
+  {
+    throw rabbitmq_handler_exception("Could not publish message");
+  }
+
 }
 
 void RabbitMQHandler::handleAMQPError(amqp_rpc_reply_t x, string context) throw(rabbitmq_handler_exception)

=== modified file 'plugin/rabbitmq/rabbitmq_handler.h'
--- plugin/rabbitmq/rabbitmq_handler.h	2011-03-30 19:50:29 +0000
+++ plugin/rabbitmq/rabbitmq_handler.h	2011-03-14 05:40:28 +0000
@@ -66,8 +66,6 @@
   const std::string &username;
   const std::string &password;
   const std::string &virtualhost;
-  const std::string &exchange;
-  const std::string &routingKey;
 public:
   /**
    * @brief
@@ -89,9 +87,7 @@
                   const in_port_t port, 
                   const std::string &username, 
                   const std::string &password, 
-                  const std::string &virtualhost,
-		  const std::string &exchange,
-		  const std::string &routingKey)
+                  const std::string &virtualhost)
     throw(rabbitmq_handler_exception);
 
   ~RabbitMQHandler();
@@ -105,14 +101,16 @@
    *
    * @param[in] message the message to send
    * @param[in] length the length of the message
+   * @param[in] exchangeName name of the exchange to publish to
+   * @param[in] routingKey the routing key to use
    * @throw exception if there is a problem publishing
    */
   void publish(void *message, 
-               const int length)
+               const int length, 
+               const std::string &exchangeName, 
+               const std::string &routingKey)
     throw(rabbitmq_handler_exception);
 
-  void reconnect() throw(rabbitmq_handler_exception);
-  void disconnect() throw(rabbitmq_handler_exception);
 
 private:
   /**
@@ -128,9 +126,6 @@
    * @throw exception with the message unless the command was successful
    */
   void handleAMQPError(amqp_rpc_reply_t x, std::string context) throw(rabbitmq_handler_exception);
-
-  void connect() throw(rabbitmq_handler_exception);
-
 };
 
 } /* namespace drizzle_plugin */

=== modified file 'plugin/rabbitmq/rabbitmq_log.cc'
--- plugin/rabbitmq/rabbitmq_log.cc	2011-03-30 19:50:29 +0000
+++ plugin/rabbitmq/rabbitmq_log.cc	2011-02-17 00:14:13 +0000
@@ -50,16 +50,17 @@
 
 
 RabbitMQLog::RabbitMQLog(const string &name, 
+                         const std::string &exchange,
+                         const std::string &routingkey,
                          RabbitMQHandler* mqHandler) :
   plugin::TransactionApplier(name),
-  _rabbitMQHandler(mqHandler)
+  _rabbitMQHandler(mqHandler),
+  _exchange(exchange),
+  _routingkey(routingkey)
 { }
 
 RabbitMQLog::~RabbitMQLog() 
-{ 
-  _rabbitMQHandler->disconnect();
-  delete _rabbitMQHandler;
-}
+{ }
 
 plugin::ReplicationReturnCode
 RabbitMQLog::apply(Session &, const message::Transaction &to_apply)
@@ -74,38 +75,26 @@
   }
 
   to_apply.SerializeWithCachedSizesToArray(buffer);
-  short tries = 3;
-  bool sent = false;
-  while (!sent && tries > 0) {
-    tries--;
-    try
-    {
-      _rabbitMQHandler->publish(buffer, int(message_byte_length));
-      sent = true;
-    } 
-    catch(exception& e)
-    {
-      errmsg_printf(error::ERROR, _(e.what()));
-      try {
-  	_rabbitMQHandler->reconnect();
-      } catch(exception &e) {
-  	errmsg_printf(error::ERROR, _("Could not reconnect, trying again.. - waiting 10 seconds for server to come back"));
-  	sleep(10);
-      } // 
-    }
-  }
-
+  try
+  {
+    _rabbitMQHandler->publish(buffer, 
+                             int(message_byte_length), 
+                             _exchange,
+                             _routingkey);
+  }
+  catch(exception& e)
+  {
+    errmsg_printf(error::ERROR, _(e.what()));
+    deactivate();
+    return plugin::UNKNOWN_ERROR;
+  }
   delete[] buffer;
-  if(sent) return plugin::SUCCESS;
-  errmsg_printf(error::ERROR, _("RabbitMQ server has disappeared, failing transaction."));
-  deactivate();
-  return plugin::UNKNOWN_ERROR;
+  return plugin::SUCCESS;
 }
 
 static RabbitMQLog *rabbitmqLogger; ///< the actual plugin
 static RabbitMQHandler* rabbitmqHandler; ///< the rabbitmq handler
 
-
 /**
  * Initialize the rabbitmq logger - instanciates the dependencies (the handler)
  * and creates the log handler with the dependency - makes it easier to swap out
@@ -121,9 +110,7 @@
                                          sysvar_rabbitmq_port, 
                                          vm["username"].as<string>(), 
                                          vm["password"].as<string>(), 
-                                         vm["virtualhost"].as<string>(),
-					 vm["exchange"].as<string>(),
-					 vm["routingkey"].as<string>());
+                                         vm["virtualhost"].as<string>());
   } 
   catch (exception& e) 
   {
@@ -134,6 +121,8 @@
   try 
   {
     rabbitmqLogger= new RabbitMQLog("rabbit_log_applier",
+                                    vm["exchange"].as<string>(),
+                                    vm["routingkey"].as<string>(),
                                     rabbitmqHandler);
   } 
   catch (exception& e) 

=== modified file 'plugin/rabbitmq/rabbitmq_log.h'
--- plugin/rabbitmq/rabbitmq_log.h	2011-03-30 19:50:29 +0000
+++ plugin/rabbitmq/rabbitmq_log.h	2011-03-14 05:40:28 +0000
@@ -61,6 +61,8 @@
    * @param[in] mqHandler name of the plugin, typically rabbitmq_log.
    */
   RabbitMQLog(const std::string &name,
+              const std::string &exchange,
+              const std::string &routingkey,
               RabbitMQHandler* mqHandler);
   ~RabbitMQLog();
 

